##  Copyright (C) 2014  Daniel Kraft <d@domob.eu>
##  GNU Octave level-set package.
##
##  This program is free software: you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation, either version 3 of the License, or
##  (at your option) any later version.
##
##  This program is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU General Public License for more details.
##
##  You should have received a copy of the GNU General Public License
##  along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn  {Function File} {} ls_animate_evolution (@var{phi}, @var{f}, @var{h}, @var{times}, @var{wait})
## 
## Animate the evolution of a level-set geometry.  The evolution
## is calculated with @code{ls_solve_stationary} and @code{ls_extract_solution}
## for the given arguments,  and the result plotted in the current figure
## for the times given in @var{times}.  Between updating to the next
## ``movie frame'', sleep for @var{wait} seconds.
##
## @seealso{ls_solve_stationary, ls_extract_solution}
## @end deftypefn

function ls_animate_evolution (phi, f, h, times, wait)
  d = ls_solve_stationary (phi, f, h);
  for t = times
    phit = ls_extract_solution (t, d, phi, f);
    clf ();
    hold ("on");
    imagesc (f);
    set (gca (), "ydir", "normal");
    colormap (ls_sign_colourmap (caxis ()));
    contour (phit, [0, 0], "k");
    hold ("off");
    axis ("equal");
    drawnow ();
    sleep (wait);
  endfor
endfunction

% Simple demo with a basic situation.
%!demo
%!  n = 100;
%!  x = linspace (-2, 2, n);
%!  h = x(2) - x(1);
%!  [XX, YY] = meshgrid (x, x);
%!
%!  phi = XX.^2 + YY.^2 - 1.7^2;
%!  f = -XX.^2 - YY.^2;
%!
%!  times = linspace (0, 1, 15);
%!  ls_animate_evolution (phi, f, h, times, 0.2);
