##  Copyright (C) 2014  Daniel Kraft <d@domob.eu>
##  GNU Octave level-set package.
##
##  This program is free software: you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation, either version 3 of the License, or
##  (at your option) any later version.
##
##  This program is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU General Public License for more details.
##
##  You should have received a copy of the GNU General Public License
##  along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn  {Function File} {@var{phi} =} ls_complement (@var{phi})
## 
## Construct a level-set function for the complement of the set
## described by @var{phi}.
##
## @seealso{ls_union, ls_intersect, ls_setdiff, ls_setxor}
## @end deftypefn

function phi = ls_complement (phi)
  if (nargin () ~= 1)
    usage ("wrong number of arguments");
  endif
  if (nargout () > 1)
    usage ("too many output arguments requested");
  endif

  phi = -phi;
endfunction

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Tests.

% Test for error conditions.
%!error <wrong number of arguments>
%!  ls_complement ()
%!error <wrong number of arguments>
%!  ls_complement (1, 2)
%!error <too many output arguments requested>
%!  [a, b] = ls_complement (1);

% Basic tests for the function.
%!test
%!  n = 50;
%!  x = linspace (-10, 10, n);
%!  [XX, YY] = meshgrid (x, x);
%!
%!  phi1 = (XX - 2).^2 + (YY - 2).^2 - 2^2;
%!  phi2 = (XX + 2).^2 + (YY + 2).^2 - 2^2;
%!
%!  assert (ls_disjoint (phi1, ls_complement (phi1)));
%!  assert (ls_disjoint (phi2, ls_complement (phi2)));
%!
%!  assert (~ls_disjoint (phi1, ls_complement (phi2)));
%!  assert (~ls_disjoint (phi2, ls_complement (phi1)));
