##  Copyright (C) 2014  Daniel Kraft <d@domob.eu>
##  GNU Octave level-set package.
##
##  This program is free software: you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation, either version 3 of the License, or
##  (at your option) any later version.
##
##  This program is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU General Public License for more details.
##
##  You should have received a copy of the GNU General Public License
##  along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn  {Function File} {@var{where} =} ls_inside (@var{phi})
## 
## Return in a logical array which points are inside the domain
## described by the level-set function @var{phi}.  These are the points
## where @var{phi} is negative.
##
## @seealso{ls_check, ls_issubset}
## @end deftypefn

function res = ls_inside (phi)
  if (nargin () ~= 1)
    usage ("wrong number of arguments");
  endif
  if (nargout () > 1)
    usage ("too many output arguments requested");
  endif

  res = (phi < 0);
endfunction

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Tests.

% Test for error conditions.
%!error <wrong number of arguments>
%!  ls_inside ()
%!error <wrong number of arguments>
%!  ls_inside (1, 2)
%!error <too many output arguments requested>
%!  [a, b] = ls_inside (1);

% Basic test.
%!test
%!  assert (ls_inside ([1, 0, -1, 0, 1]), [false, false, true, false, false]);
